package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.UserServiceFeign;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.UserDTO;
import com.bwie.common.myException.MyException;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class AuthServiceImpl implements AuthService {
    @Resource
    private UserServiceFeign userServiceFeign;
    @Resource
    private StringRedisTemplate stringRedisTemplate;
    @Resource
    private HttpServletRequest httpServletRequest;
    @Override
    public Result login(User user) {
        if (StringUtils.isBlank(user.getUserName())){
            throw new MyException("账号不能为空");
        }
        Result<User> result = userServiceFeign.selUser(user);
        User user1 = result.getData();
        if (user1==null){
            throw new MyException("用户不存在");
        }
        if (!user1.getPassword().equals(user.getPassword())){
            throw new MyException("密码错误");
        }
        String userKey = UUID.randomUUID().toString().replaceAll("-", "");
        HashMap<String, Object> map = new HashMap<>();
        map.put(JwtConstants.USER_KEY,userKey);
        String token = JwtUtils.createToken(map);
        stringRedisTemplate.opsForValue().set(JwtConstants.USER_KEY+userKey, JSONObject.toJSONString(user1),15, TimeUnit.MINUTES);
        UserDTO userDTO = new UserDTO();
        userDTO.setToken(token);
        userDTO.setExTime("15分钟");
        return Result.success(userDTO);
    }

    @Override
    public Result getInfo() {
        String token = httpServletRequest.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        String s = stringRedisTemplate.opsForValue().get(JwtConstants.USER_KEY + userKey);
        User user = JSONObject.parseObject(s, User.class);
        return Result.success(user);
    }
}
