package com.bwie.resume.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.Resume;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.ResumeVo;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.resume.mapper.ResumeMapper;
import com.bwie.resume.service.ResumeService;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.UUID;

@Service
public class ResumeServiceImpl implements ResumeService {
    @Resource
    private ResumeMapper resumeMapper;
    @Resource
    private HttpServletRequest httpServletRequest;
    @Resource
    private StringRedisTemplate stringRedisTemplate;
    @Resource
    private RabbitTemplate rabbitTemplate;
    @Override
    public List<ResumeVo> selResumeVoList() {
        return resumeMapper.selResumeVoList();
    }

    @Override
    public Result addResume(Resume resume) {
        String token = httpServletRequest.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        String s = stringRedisTemplate.opsForValue().get(JwtConstants.USER_KEY + userKey);
        User user = JSONObject.parseObject(s, User.class);
        Resume resume1 = resumeMapper.selByUserIdAndPostId(user.getUserId(), resume.getPostId());
        if (resume1==null){
            resume.setUserId(user.getUserId());
            Integer i = resumeMapper.addResume(resume);
            if (i>0){
                resumeMapper.updPostNum(resume.getPostId());
                resumeMapper.updUserNum(user.getUserId());
                return Result.success(200,"简历投递成功");
            }
        }
        return Result.error("您已投递简历,请耐心等待");
    }

    @Override
    public Integer passResumeStatus(Integer resumeId) {
        Integer i = resumeMapper.passResumeStatus(resumeId);
        if (i>0){
            String userPhone = resumeMapper.selUserPhoneByResumeId(resumeId);
            rabbitTemplate.convertAndSend("PassSendSms",userPhone,message -> {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });
        }
        return i;
    }

    @Override
    public Integer backResumeStatus(Integer resumeId) {
        Integer i = resumeMapper.backResumeStatus(resumeId);
        if (i>0){
            String userPhone = resumeMapper.selUserPhoneByResumeId(resumeId);
            rabbitTemplate.convertAndSend("BackSendSms",userPhone,message -> {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });
        }
        return i;
    }
}
